@@ -94,6 +94,7 @@ def apply_pnl(row):
             if date == open_date:
                 # Unrealized pnl on the open date, record on df_daily
                 df_daily.at[open_date, 'action'] = 'open'
+                df_daily.at[open_date, 'signal_value'] = df_daily.at[open_date, 'bah']  # Mark the open position for analysi chart
 
                 unrealized_pnl = num_of_share * multiplier * (now_close - open_price)#  - commission
                 unrealized_pnl = round(unrealized_pnl, 3)
@@ -449,6 +450,7 @@ def resample_summary_to_daily(para_combination, folder=''):
         pl.lit(None).alias('action'),
         pl.lit(None).alias('realized_pnl'),
         pl.lit(None).alias('unrealized_pnl'),
+        pl.lit(None).alias('signal_value'),   # for the position of analysis chart
         pl.lit(None).alias('commission'),
     ])
           .collect()
@@ -457,7 +459,7 @@ def resample_summary_to_daily(para_combination, folder=''):
     df_daily = df.to_pandas()
     df_daily.index = pd.to_datetime(df_daily['datetime'], format='%Y-%m-%d')
 
-    # Apply apply_pnl on backtes here
+    # Apply apply_pnl on backtest here
     apply_pnl.last_realized_capital = last_realized_capital
     apply_pnl.multiplier = multiplier
     apply_pnl.df_daily = df_daily
