@@ -92,10 +92,12 @@ class Plot:
 
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
-        my_css_data = """body {
+        my_css_data = """
+                body {
                   background-color: #1a2245;
                 }
-                        /* width */
+                
+                /* width */
                 ::-webkit-scrollbar {
                   width: 10px !important;
                   display: block !important;
@@ -114,6 +116,7 @@ class Plot:
                   background: #154360;
                   border-radius: 10px;
                 }
+                
                 """
         innerHtmlText = "<style>%s</style>" % my_css_data
 
@@ -206,7 +209,7 @@ class Plot:
                                   html.Div(children=dbc.Row([
                                                 dbc.Col(width=1),
                                                 dbc.Col(children=html.Div([
-                                                    html.Div(style={'height': '0.5px'}),
+                                                    html.Div(style={'height': '0.5px',}),
                                                     dcc.DatePickerRange(
                                                         id='chart3_date',
                                                         style={'margin-left':'15px'},
